==> failsafe-actuator-0.1-sources.jar: org/zalando/failsafeactuator/endpoint/domain/CircuitBreakerState.java <==
/**
 * The MIT License (MIT)
 * Copyright (c) 2016 Zalando SE
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package org.zalando.failsafeactuator.endpoint.domain;

/**
 * Represents the state and identifier of an {@link net.jodah.failsafe.CircuitBreaker}.
 *
 * @author mpickhan on 29.06.16.
 */
public class CircuitBreakerState {

    private String name;

    private boolean isClosed;

    public CircuitBreakerState() {

    }

    public CircuitBreakerState(final String name, final boolean isClosed) {
        this.name = name;
        this.isClosed = isClosed;
    }

    public boolean isClosed() {
        return this.isClosed;
    }

    public void setClosed(final boolean closed) {
        isClosed = closed;
    }

    public String getName() {
        return this.name;
    }

    public void setName(final String name) {
        this.name = name;
    }

    @Override
    public String toString() {
        return "CircuitBreakerState{" +
                "name='" + name + '\'' +
                ", isClosed=" + isClosed +
                '}';
    }
}

==> failsafe-actuator-0.3.0-sources.jar: org/zalando/failsafeactuator/endpoint/domain/CircuitBreakerState.java <==
/**
 * The MIT License (MIT)
 * Copyright (c) 2016 Zalando SE
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package org.zalando.failsafeactuator.endpoint.domain;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.ToString;

/**
 * Represents the state and identifier of an {@link net.jodah.failsafe.CircuitBreaker}.
 *
 * @author mpickhan on 29.06.16.
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@ToString
public class CircuitBreakerState {

  private String name;

  private boolean closed;

  private boolean open;

  private boolean halfOpen;
}
